@@ -9,15 +9,21 @@ types: list[str] = [
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
+    "AWS::AmazonMQ::Broker",
+    "AWS::AmazonMQ::Configuration",
+    "AWS::AmazonMQ::ConfigurationAssociation",
     "AWS::ApiGateway::Account",
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -38,6 +44,10 @@ types: list[str] = [
     "AWS::AppConfig::HostedConfigurationVersion",
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
+    "AWS::Athena::DataCatalog",
+    "AWS::Athena::NamedQuery",
+    "AWS::Athena::PreparedStatement",
+    "AWS::Athena::WorkGroup",
     "AWS::AutoScaling::AutoScalingGroup",
     "AWS::AutoScaling::LaunchConfiguration",
     "AWS::AutoScaling::LifecycleHook",
@@ -48,12 +58,16 @@ types: list[str] = [
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
     "AWS::CDK::Metadata",
     "AWS::CertificateManager::Certificate",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::HookDefaultVersion",
+    "AWS::CloudFormation::HookTypeConfig",
+    "AWS::CloudFormation::HookVersion",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::ResourceDefaultVersion",
     "AWS::CloudFormation::ResourceVersion",
@@ -64,8 +78,10 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
+    "AWS::CloudFront::DistributionTenant",
     "AWS::CloudFront::Function",
     "AWS::CloudFront::KeyGroup",
     "AWS::CloudFront::KeyValueStore",
@@ -79,19 +95,25 @@ types: list[str] = [
     "AWS::CloudWatch::Alarm",
     "AWS::CloudWatch::AnomalyDetector",
     "AWS::CloudWatch::CompositeAlarm",
+    "AWS::CloudWatch::Dashboard",
     "AWS::CloudWatch::InsightRule",
+    "AWS::CloudWatch::MetricStream",
     "AWS::CodeDeploy::Application",
     "AWS::CodeDeploy::DeploymentConfig",
     "AWS::CodeDeploy::DeploymentGroup",
     "AWS::CodePipeline::CustomActionType",
     "AWS::CodePipeline::Pipeline",
+    "AWS::Config::AggregationAuthorization",
     "AWS::Config::ConfigRule",
+    "AWS::Config::ConfigurationAggregator",
     "AWS::Config::ConfigurationRecorder",
     "AWS::Config::DeliveryChannel",
+    "AWS::Config::StoredQuery",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DataPipeline::Pipeline",
     "AWS::DataSync::Agent",
     "AWS::DataSync::LocationAzureBlob",
+    "AWS::DataSync::LocationEFS",
     "AWS::DataSync::LocationHDFS",
     "AWS::DataSync::LocationNFS",
     "AWS::DataSync::LocationObjectStorage",
@@ -102,6 +124,7 @@ types: list[str] = [
     "AWS::DirectoryService::SimpleAD",
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
+    "AWS::EC2::CapacityReservation",
     "AWS::EC2::CustomerGateway",
     "AWS::EC2::DHCPOptions",
     "AWS::EC2::EC2Fleet",
@@ -111,6 +134,13 @@ types: list[str] = [
     "AWS::EC2::FlowLog",
     "AWS::EC2::GatewayRouteTableAssociation",
     "AWS::EC2::Host",
+    "AWS::EC2::IPAM",
+    "AWS::EC2::IPAMAllocation",
+    "AWS::EC2::IPAMPool",
+    "AWS::EC2::IPAMPoolCidr",
+    "AWS::EC2::IPAMResourceDiscovery",
+    "AWS::EC2::IPAMResourceDiscoveryAssociation",
+    "AWS::EC2::IPAMScope",
     "AWS::EC2::Instance",
     "AWS::EC2::InternetGateway",
     "AWS::EC2::KeyPair",
@@ -122,6 +152,7 @@ types: list[str] = [
     "AWS::EC2::NetworkInterfaceAttachment",
     "AWS::EC2::NetworkInterfacePermission",
     "AWS::EC2::PlacementGroup",
+    "AWS::EC2::PrefixList",
     "AWS::EC2::Route",
     "AWS::EC2::RouteTable",
     "AWS::EC2::SecurityGroup",
@@ -143,6 +174,7 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
     "AWS::EC2::TransitGatewayMulticastGroupSource",
+    "AWS::EC2::TransitGatewayPeeringAttachment",
     "AWS::EC2::TransitGatewayRoute",
     "AWS::EC2::TransitGatewayRouteTable",
     "AWS::EC2::TransitGatewayRouteTableAssociation",
@@ -177,6 +209,7 @@ types: list[str] = [
     "AWS::ECS::Service",
     "AWS::ECS::TaskDefinition",
     "AWS::ECS::TaskSet",
+    "AWS::EFS::AccessPoint",
     "AWS::EFS::FileSystem",
     "AWS::EFS::MountTarget",
     "AWS::EKS::AccessEntry",
@@ -195,6 +228,7 @@ types: list[str] = [
     "AWS::ElastiCache::ReplicationGroup",
     "AWS::ElastiCache::SecurityGroup",
     "AWS::ElastiCache::SecurityGroupIngress",
+    "AWS::ElastiCache::ServerlessCache",
     "AWS::ElastiCache::SubnetGroup",
     "AWS::ElastiCache::User",
     "AWS::ElastiCache::UserGroup",
@@ -208,12 +242,40 @@ types: list[str] = [
     "AWS::ElasticLoadBalancingV2::ListenerRule",
     "AWS::ElasticLoadBalancingV2::LoadBalancer",
     "AWS::ElasticLoadBalancingV2::TargetGroup",
+    "AWS::ElasticLoadBalancingV2::TrustStore",
+    "AWS::ElasticLoadBalancingV2::TrustStoreRevocation",
     "AWS::Elasticsearch::Domain",
     "AWS::Events::EventBus",
     "AWS::Events::Rule",
+    "AWS::FMS::NotificationChannel",
+    "AWS::FMS::Policy",
+    "AWS::FMS::ResourceSet",
     "AWS::GameLift::Alias",
     "AWS::GameLift::Build",
     "AWS::GameLift::Fleet",
+    "AWS::Glue::Classifier",
+    "AWS::Glue::Connection",
+    "AWS::Glue::Crawler",
+    "AWS::Glue::CustomEntityType",
+    "AWS::Glue::DataCatalogEncryptionSettings",
+    "AWS::Glue::DataQualityRuleset",
+    "AWS::Glue::Database",
+    "AWS::Glue::DevEndpoint",
+    "AWS::Glue::Job",
+    "AWS::Glue::MLTransform",
+    "AWS::Glue::Partition",
+    "AWS::Glue::SecurityConfiguration",
+    "AWS::Glue::Table",
+    "AWS::Glue::Trigger",
+    "AWS::Glue::Workflow",
+    "AWS::GuardDuty::Detector",
+    "AWS::GuardDuty::Filter",
+    "AWS::GuardDuty::IPSet",
+    "AWS::GuardDuty::MalwareProtectionPlan",
+    "AWS::GuardDuty::Master",
+    "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::PublishingDestination",
+    "AWS::GuardDuty::ThreatIntelSet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
     "AWS::IAM::GroupPolicy",
@@ -229,6 +291,16 @@ types: list[str] = [
     "AWS::IAM::User",
     "AWS::IAM::UserPolicy",
     "AWS::IAM::UserToGroupAddition",
+    "AWS::IdentityStore::Group",
+    "AWS::IdentityStore::GroupMembership",
+    "AWS::ImageBuilder::Component",
+    "AWS::ImageBuilder::ContainerRecipe",
+    "AWS::ImageBuilder::DistributionConfiguration",
+    "AWS::ImageBuilder::Image",
+    "AWS::ImageBuilder::ImagePipeline",
+    "AWS::ImageBuilder::ImageRecipe",
+    "AWS::ImageBuilder::InfrastructureConfiguration",
+    "AWS::ImageBuilder::Workflow",
     "AWS::IoT::Certificate",
     "AWS::IoT::Policy",
     "AWS::IoT::PolicyPrincipalAttachment",
@@ -241,7 +313,15 @@ types: list[str] = [
     "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
+    "AWS::KinesisAnalyticsV2::Application",
     "AWS::KinesisFirehose::DeliveryStream",
+    "AWS::LakeFormation::DataCellsFilter",
+    "AWS::LakeFormation::DataLakeSettings",
+    "AWS::LakeFormation::Permissions",
+    "AWS::LakeFormation::PrincipalPermissions",
+    "AWS::LakeFormation::Resource",
+    "AWS::LakeFormation::Tag",
+    "AWS::LakeFormation::TagAssociation",
     "AWS::Lambda::Alias",
     "AWS::Lambda::EventInvokeConfig",
     "AWS::Lambda::EventSourceMapping",
@@ -250,6 +330,9 @@ types: list[str] = [
     "AWS::Lambda::LayerVersionPermission",
     "AWS::Lambda::Permission",
     "AWS::Lambda::Version",
+    "AWS::Logs::Delivery",
+    "AWS::Logs::DeliveryDestination",
+    "AWS::Logs::DeliverySource",
     "AWS::Logs::Destination",
     "AWS::Logs::LogGroup",
     "AWS::Logs::LogStream",
@@ -257,6 +340,11 @@ types: list[str] = [
     "AWS::Logs::QueryDefinition",
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
+    "AWS::NetworkFirewall::Firewall",
+    "AWS::NetworkFirewall::FirewallPolicy",
+    "AWS::NetworkFirewall::LoggingConfiguration",
+    "AWS::NetworkFirewall::RuleGroup",
+    "AWS::NetworkFirewall::TLSInspectionConfiguration",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
     "AWS::OpenSearchService::Domain",
@@ -267,11 +355,20 @@ types: list[str] = [
     "AWS::OpsWorks::Stack",
     "AWS::OpsWorks::UserProfile",
     "AWS::OpsWorks::Volume",
+    "AWS::Organizations::Account",
+    "AWS::Organizations::Organization",
+    "AWS::Organizations::OrganizationalUnit",
+    "AWS::Organizations::Policy",
+    "AWS::Organizations::ResourcePolicy",
+    "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
     "AWS::RDS::DBCluster",
     "AWS::RDS::DBClusterParameterGroup",
     "AWS::RDS::DBInstance",
     "AWS::RDS::DBParameterGroup",
+    "AWS::RDS::DBProxy",
+    "AWS::RDS::DBProxyEndpoint",
+    "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
     "AWS::RDS::DBSubnetGroup",
@@ -286,13 +383,28 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
+    "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Workgroup",
+    "AWS::ResourceExplorer2::DefaultViewAssociation",
+    "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
+    "AWS::RolesAnywhere::CRL",
+    "AWS::RolesAnywhere::Profile",
+    "AWS::RolesAnywhere::TrustAnchor",
+    "AWS::Route53::CidrCollection",
     "AWS::Route53::HealthCheck",
     "AWS::Route53::HostedZone",
     "AWS::Route53::RecordSet",
     "AWS::Route53::RecordSetGroup",
+    "AWS::Route53Resolver::FirewallDomainList",
+    "AWS::Route53Resolver::FirewallRuleGroup",
+    "AWS::Route53Resolver::FirewallRuleGroupAssociation",
+    "AWS::Route53Resolver::ResolverConfig",
     "AWS::Route53Resolver::ResolverEndpoint",
+    "AWS::Route53Resolver::ResolverQueryLoggingConfig",
+    "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation",
     "AWS::Route53Resolver::ResolverRule",
     "AWS::Route53Resolver::ResolverRuleAssociation",
     "AWS::S3::AccessPoint",
@@ -316,10 +428,20 @@ types: list[str] = [
     "AWS::SSM::Parameter",
     "AWS::SSM::PatchBaseline",
     "AWS::SSM::ResourceDataSync",
+    "AWS::SageMaker::ModelCard",
+    "AWS::SageMaker::Pipeline",
     "AWS::SecretsManager::ResourcePolicy",
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
     "AWS::SecretsManager::SecretTargetAttachment",
+    "AWS::SecurityHub::AutomationRule",
+    "AWS::SecurityHub::DelegatedAdmin",
+    "AWS::SecurityHub::Hub",
+    "AWS::SecurityHub::Insight",
+    "AWS::SecurityHub::OrganizationConfiguration",
+    "AWS::SecurityHub::ProductSubscription",
+    "AWS::SecurityHub::SecurityControl",
+    "AWS::SecurityHub::Standard",
     "AWS::ServiceDiscovery::HttpNamespace",
     "AWS::ServiceDiscovery::Instance",
     "AWS::ServiceDiscovery::PrivateDnsNamespace",
@@ -337,6 +459,12 @@ types: list[str] = [
     "AWS::WAF::SqlInjectionMatchSet",
     "AWS::WAF::WebACL",
     "AWS::WAF::XssMatchSet",
+    "AWS::WAFv2::IPSet",
+    "AWS::WAFv2::LoggingConfiguration",
+    "AWS::WAFv2::RegexPatternSet",
+    "AWS::WAFv2::RuleGroup",
+    "AWS::WAFv2::WebACL",
+    "AWS::WAFv2::WebACLAssociation",
     "AWS::WorkSpaces::Workspace",
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
@@ -352,42 +480,63 @@ cached: list[str] = [
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
+    "aws-amazonmq-broker.json",
+    "aws-amazonmq-configuration.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
     "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
     "aws-apigateway-clientcertificate.json",
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
+    "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
+    "aws-appconfig-deployment.json",
+    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
+    "aws-athena-datacatalog.json",
+    "aws-athena-namedquery.json",
+    "aws-athena-preparedstatement.json",
+    "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
+    "aws-autoscaling-launchconfiguration.json",
+    "aws-autoscaling-lifecyclehook.json",
+    "aws-autoscaling-scalingpolicy.json",
+    "aws-autoscaling-scheduledaction.json",
     "aws-autoscaling-warmpool.json",
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-certificatemanager-certificate.json",
     "aws-cloudformation-customresource.json",
+    "aws-cloudformation-hookdefaultversion.json",
+    "aws-cloudformation-hooktypeconfig.json",
+    "aws-cloudformation-hookversion.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-resourcedefaultversion.json",
     "aws-cloudformation-resourceversion.json",
@@ -396,8 +545,10 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distribution.json",
+    "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -412,11 +563,17 @@ cached: list[str] = [
     "aws-cloudwatch-anomalydetector.json",
     "aws-cloudwatch-compositealarm.json",
     "aws-cloudwatch-insightrule.json",
+    "aws-cloudwatch-metricstream.json",
     "aws-codedeploy-deploymentgroup.json",
+    "aws-config-aggregationauthorization.json",
+    "aws-config-configrule.json",
+    "aws-config-configurationaggregator.json",
     "aws-config-configurationrecorder.json",
     "aws-config-deliverychannel.json",
+    "aws-config-storedquery.json",
     "aws-datasync-agent.json",
     "aws-datasync-locationazureblob.json",
+    "aws-datasync-locationefs.json",
     "aws-datasync-locationhdfs.json",
     "aws-datasync-locationnfs.json",
     "aws-datasync-locationobjectstorage.json",
@@ -424,20 +581,34 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
     "aws-dlm-lifecyclepolicy.json",
+    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
+    "aws-ec2-capacityreservation.json",
+    "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
+    "aws-ec2-eip.json",
     "aws-ec2-flowlog.json",
     "aws-ec2-gatewayroutetableassociation.json",
+    "aws-ec2-instance.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
+    "aws-ec2-ipamallocation.json",
+    "aws-ec2-ipampool.json",
+    "aws-ec2-ipampoolcidr.json",
+    "aws-ec2-ipamresourcediscovery.json",
+    "aws-ec2-ipamresourcediscoveryassociation.json",
+    "aws-ec2-ipamscope.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinterface.json",
+    "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-placementgroup.json",
+    "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
     "aws-ec2-routetable.json",
     "aws-ec2-securitygroup.json",
@@ -447,6 +618,7 @@ cached: list[str] = [
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
+    "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
@@ -457,19 +629,28 @@ cached: list[str] = [
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
     "aws-ec2-transitgatewaymulticastgroupsource.json",
+    "aws-ec2-transitgatewaypeeringattachment.json",
     "aws-ec2-transitgatewayroute.json",
     "aws-ec2-transitgatewayroutetable.json",
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-volume.json",
+    "aws-ec2-volumeattachment.json",
+    "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
     "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
+    "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
+    "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
+    "aws-ec2-vpnconnection.json",
+    "aws-ec2-vpnconnectionroute.json",
+    "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
@@ -483,6 +664,9 @@ cached: list[str] = [
     "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
+    "aws-efs-accesspoint.json",
+    "aws-efs-filesystem.json",
+    "aws-efs-mounttarget.json",
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
     "aws-eks-cluster.json",
@@ -493,17 +677,46 @@ cached: list[str] = [
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
+    "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
+    "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
+    "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-targetgroup.json",
+    "aws-elasticloadbalancingv2-truststore.json",
+    "aws-elasticloadbalancingv2-truststorerevocation.json",
     "aws-elasticsearch-domain.json",
     "aws-emr-cluster.json",
     "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
+    "aws-emr-step.json",
     "aws-events-eventbus.json",
     "aws-events-rule.json",
+    "aws-fms-notificationchannel.json",
+    "aws-fms-resourceset.json",
+    "aws-glue-classifier.json",
+    "aws-glue-connection.json",
+    "aws-glue-customentitytype.json",
+    "aws-glue-datacatalogencryptionsettings.json",
+    "aws-glue-dataqualityruleset.json",
+    "aws-glue-devendpoint.json",
+    "aws-glue-job.json",
+    "aws-glue-mltransform.json",
+    "aws-glue-partition.json",
+    "aws-glue-securityconfiguration.json",
+    "aws-glue-table.json",
+    "aws-glue-trigger.json",
+    "aws-glue-workflow.json",
+    "aws-guardduty-detector.json",
+    "aws-guardduty-filter.json",
+    "aws-guardduty-ipset.json",
+    "aws-guardduty-malwareprotectionplan.json",
+    "aws-guardduty-master.json",
+    "aws-guardduty-member.json",
+    "aws-guardduty-publishingdestination.json",
+    "aws-guardduty-threatintelset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
@@ -518,24 +731,52 @@ cached: list[str] = [
     "aws-iam-user.json",
     "aws-iam-userpolicy.json",
     "aws-iam-usertogroupaddition.json",
+    "aws-identitystore-group.json",
+    "aws-identitystore-groupmembership.json",
+    "aws-imagebuilder-component.json",
+    "aws-imagebuilder-containerrecipe.json",
+    "aws-imagebuilder-distributionconfiguration.json",
+    "aws-imagebuilder-image.json",
+    "aws-imagebuilder-imagepipeline.json",
+    "aws-imagebuilder-imagerecipe.json",
+    "aws-imagebuilder-infrastructureconfiguration.json",
+    "aws-imagebuilder-workflow.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
+    "aws-kinesisanalyticsv2-application.json",
+    "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
+    "aws-lakeformation-datacellsfilter.json",
+    "aws-lakeformation-datalakesettings.json",
+    "aws-lakeformation-permissions.json",
+    "aws-lakeformation-principalpermissions.json",
+    "aws-lakeformation-resource.json",
+    "aws-lakeformation-tag.json",
+    "aws-lakeformation-tagassociation.json",
+    "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
+    "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
+    "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
+    "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-networkfirewall-firewall.json",
+    "aws-networkfirewall-firewallpolicy.json",
+    "aws-networkfirewall-loggingconfiguration.json",
+    "aws-networkfirewall-rulegroup.json",
+    "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-opensearchservice-domain.json",
@@ -543,15 +784,23 @@ cached: list[str] = [
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
     "aws-opsworks-volume.json",
+    "aws-organizations-account.json",
+    "aws-organizations-organization.json",
+    "aws-organizations-organizationalunit.json",
+    "aws-organizations-policy.json",
+    "aws-organizations-resourcepolicy.json",
+    "aws-ram-permission.json",
+    "aws-ram-resourceshare.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
-    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
+    "aws-rds-dbproxy.json",
+    "aws-rds-dbproxyendpoint.json",
+    "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
-    "aws-rds-globalcluster.json",
     "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
     "aws-redshift-clusterparametergroup.json",
@@ -561,24 +810,54 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
+    "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-workgroup.json",
+    "aws-resourceexplorer2-defaultviewassociation.json",
+    "aws-resourceexplorer2-view.json",
     "aws-resourcegroups-group.json",
+    "aws-rolesanywhere-crl.json",
+    "aws-rolesanywhere-profile.json",
+    "aws-rolesanywhere-trustanchor.json",
+    "aws-route53-cidrcollection.json",
+    "aws-route53-hostedzone.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
+    "aws-route53resolver-firewalldomainlist.json",
+    "aws-route53resolver-firewallrulegroup.json",
+    "aws-route53resolver-firewallrulegroupassociation.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverendpoint.json",
+    "aws-route53resolver-resolverqueryloggingconfig.json",
+    "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverruleassociation.json",
+    "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-sagemaker-modelcard.json",
+    "aws-sagemaker-pipeline.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
     "aws-secretsmanager-secret.json",
     "aws-secretsmanager-secrettargetattachment.json",
+    "aws-securityhub-automationrule.json",
+    "aws-securityhub-delegatedadmin.json",
+    "aws-securityhub-hub.json",
+    "aws-securityhub-insight.json",
+    "aws-securityhub-organizationconfiguration.json",
+    "aws-securityhub-productsubscription.json",
+    "aws-securityhub-securitycontrol.json",
+    "aws-securityhub-standard.json",
     "aws-servicediscovery-httpnamespace.json",
     "aws-servicediscovery-instance.json",
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
     "aws-servicediscovery-service.json",
+    "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
     "aws-sns-topicpolicy.json",
@@ -600,6 +879,10 @@ cached: list[str] = [
     "aws-synthetics-canary.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
+    "aws-wafv2-ipset.json",
+    "aws-wafv2-loggingconfiguration.json",
+    "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
