@@ -110,6 +110,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
+    "AWS::ApplicationSignals::Discovery",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -134,6 +135,7 @@ types: list[str] = [
     "AWS::Backup::RestoreTestingSelection",
     "AWS::BackupGateway::Hypervisor",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
@@ -194,8 +196,10 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
+    "AWS::CloudFront::DistributionTenant",
     "AWS::CloudFront::Function",
     "AWS::CloudFront::KeyGroup",
     "AWS::CloudFront::KeyValueStore",
@@ -341,6 +345,7 @@ types: list[str] = [
     "AWS::DataSync::LocationSMB",
     "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
+    "AWS::DataZone::Connection",
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
     "AWS::DataZone::Environment",
@@ -603,6 +608,7 @@ types: list[str] = [
     "AWS::GuardDuty::MalwareProtectionPlan",
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::PublishingDestination",
     "AWS::GuardDuty::ThreatIntelSet",
     "AWS::HealthLake::FHIRDatastore",
     "AWS::IAM::AccessKey",
@@ -837,10 +843,6 @@ types: list[str] = [
     "AWS::NetworkManager::TransitGatewayRegistration",
     "AWS::NetworkManager::TransitGatewayRouteTableAttachment",
     "AWS::NetworkManager::VpcAttachment",
-    "AWS::NimbleStudio::LaunchProfile",
-    "AWS::NimbleStudio::StreamingImage",
-    "AWS::NimbleStudio::Studio",
-    "AWS::NimbleStudio::StudioComponent",
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
@@ -852,6 +854,7 @@ types: list[str] = [
     "AWS::Omics::Workflow",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::Index",
     "AWS::OpenSearchServerless::LifecyclePolicy",
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
@@ -1217,6 +1220,7 @@ types: list[str] = [
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
+    "AWS::XRay::TransactionSearchConfig",
     "Alexa::ASK::Skill",
     "Module",
 ]
@@ -1260,12 +1264,10 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -1290,6 +1292,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalabletarget.json",
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
+    "aws-applicationsignals-discovery.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -1321,6 +1324,7 @@ cached: list[str] = [
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
+    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -1351,6 +1355,7 @@ cached: list[str] = [
     "aws-backup-restoretestingselection.json",
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
@@ -1372,12 +1377,9 @@ cached: list[str] = [
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
     "aws-cassandra-type.json",
-    "aws-ce-anomalymonitor.json",
-    "aws-ce-anomalysubscription.json",
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
-    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cleanrooms-analysistemplate.json",
@@ -1411,8 +1413,10 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distribution.json",
+    "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -1463,6 +1467,7 @@ cached: list[str] = [
     "aws-cognito-managedloginbranding.json",
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
+    "aws-cognito-userpooldomain.json",
     "aws-cognito-userpoolgroup.json",
     "aws-cognito-userpoolidentityprovider.json",
     "aws-cognito-userpoolresourceserver.json",
@@ -1541,8 +1546,8 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
+    "aws-datazone-connection.json",
     "aws-datazone-datasource.json",
-    "aws-datazone-domain.json",
     "aws-datazone-environment.json",
     "aws-datazone-environmentactions.json",
     "aws-datazone-environmentblueprintconfiguration.json",
@@ -1760,8 +1765,8 @@ cached: list[str] = [
     "aws-fsx-volume.json",
     "aws-gamelift-alias.json",
     "aws-gamelift-build.json",
-    "aws-gamelift-fleet.json",
     "aws-gamelift-gameservergroup.json",
+    "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-location.json",
     "aws-gamelift-script.json",
     "aws-globalaccelerator-accelerator.json",
@@ -1814,6 +1819,7 @@ cached: list[str] = [
     "aws-guardduty-malwareprotectionplan.json",
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
+    "aws-guardduty-publishingdestination.json",
     "aws-guardduty-threatintelset.json",
     "aws-healthlake-fhirdatastore.json",
     "aws-iam-accesskey.json",
@@ -1952,7 +1958,6 @@ cached: list[str] = [
     "aws-logs-destination.json",
     "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1987,6 +1992,7 @@ cached: list[str] = [
     "aws-medialive-cluster.json",
     "aws-medialive-eventbridgeruletemplate.json",
     "aws-medialive-eventbridgeruletemplategroup.json",
+    "aws-medialive-inputsecuritygroup.json",
     "aws-medialive-multiplex.json",
     "aws-medialive-multiplexprogram.json",
     "aws-medialive-network.json",
@@ -2000,11 +2006,9 @@ cached: list[str] = [
     "aws-mediapackagev2-channel.json",
     "aws-mediapackagev2-channelgroup.json",
     "aws-mediapackagev2-channelpolicy.json",
-    "aws-mediapackagev2-originendpoint.json",
     "aws-mediapackagev2-originendpointpolicy.json",
     "aws-mediastore-container.json",
     "aws-memorydb-acl.json",
-    "aws-memorydb-cluster.json",
     "aws-memorydb-multiregioncluster.json",
     "aws-memorydb-parametergroup.json",
     "aws-memorydb-subnetgroup.json",
@@ -2045,9 +2049,6 @@ cached: list[str] = [
     "aws-networkmanager-transitgatewayregistration.json",
     "aws-networkmanager-transitgatewayroutetableattachment.json",
     "aws-networkmanager-vpcattachment.json",
-    "aws-nimblestudio-launchprofile.json",
-    "aws-nimblestudio-streamingimage.json",
-    "aws-nimblestudio-studio.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-omics-annotationstore.json",
@@ -2058,6 +2059,7 @@ cached: list[str] = [
     "aws-omics-workflow.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-index.json",
     "aws-opensearchserverless-lifecyclepolicy.json",
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
@@ -2188,6 +2190,7 @@ cached: list[str] = [
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
@@ -2356,8 +2359,6 @@ cached: list[str] = [
     "aws-voiceid-domain.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
-    "aws-vpclattice-listener.json",
-    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
@@ -2417,5 +2418,6 @@ cached: list[str] = [
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
     "aws-xray-samplingrule.json",
+    "aws-xray-transactionsearchconfig.json",
     "module.json",
 ]
