@@ -521,6 +521,11 @@ types: list[str] = [
     "AWS::MSK::ClusterPolicy",
     "AWS::MSK::Configuration",
     "AWS::MSK::VpcConnection",
+    "AWS::MemoryDB::ACL",
+    "AWS::MemoryDB::Cluster",
+    "AWS::MemoryDB::ParameterGroup",
+    "AWS::MemoryDB::SubnetGroup",
+    "AWS::MemoryDB::User",
     "AWS::Neptune::DBCluster",
     "AWS::Neptune::DBClusterParameterGroup",
     "AWS::Neptune::DBInstance",
@@ -801,8 +806,6 @@ cached: list[str] = [
     "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
-    "aws-appconfig-extension.json",
-    "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
@@ -822,6 +825,7 @@ cached: list[str] = [
     "aws-appstream-entitlement.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
+    "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
@@ -844,11 +848,11 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
+    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
-    "aws-cassandra-table.json",
     "aws-cassandra-type.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
@@ -1058,7 +1062,6 @@ cached: list[str] = [
     "aws-emr-instancegroupconfig.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
-    "aws-events-archive.json",
     "aws-events-eventbuspolicy.json",
     "aws-eventschemas-discoverer.json",
     "aws-eventschemas-registry.json",
@@ -1152,6 +1155,7 @@ cached: list[str] = [
     "aws-iot-topicrule.json",
     "aws-iot-topicruledestination.json",
     "aws-kinesis-resourcepolicy.json",
+    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
@@ -1181,7 +1185,6 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1190,12 +1193,19 @@ cached: list[str] = [
     "aws-m2-application.json",
     "aws-m2-deployment.json",
     "aws-m2-environment.json",
+    "aws-memorydb-acl.json",
+    "aws-memorydb-cluster.json",
+    "aws-memorydb-parametergroup.json",
+    "aws-memorydb-subnetgroup.json",
+    "aws-memorydb-user.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
     "aws-msk-vpcconnection.json",
     "aws-neptune-dbcluster.json",
+    "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
@@ -1232,6 +1242,7 @@ cached: list[str] = [
     "aws-quicksight-analysis.json",
     "aws-quicksight-custompermissions.json",
     "aws-quicksight-dashboard.json",
+    "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
     "aws-quicksight-refreshschedule.json",
     "aws-quicksight-template.json",
@@ -1250,13 +1261,10 @@ cached: list[str] = [
     "aws-rds-eventsubscription.json",
     "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
-    "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
-    "aws-redshift-clustersubnetgroup.json",
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
-    "aws-redshift-eventsubscription.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1281,7 +1289,6 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1386,6 +1393,7 @@ cached: list[str] = [
     "aws-transfer-profile.json",
     "aws-transfer-server.json",
     "aws-transfer-user.json",
+    "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
