@@ -7,10 +7,12 @@ from __future__ import annotations
 
 import json
 from collections import deque
+from copy import deepcopy
 from typing import Any, Iterator
 
 import regex as re
 
+from cfnlint.context.conditions.exceptions import Unsatisfiable
 from cfnlint.helpers import (
     AVAILABILITY_ZONES,
     PSEUDOPARAMS,
@@ -84,6 +86,10 @@ def find_in_map(validator: Validator, instance: Any) -> ResolutionResult:
 
         if all(not (equal(map_name, each)) for each in mappings):
             if not default_value_found:
+                # Validated again as Fn::Transform can be used along side
+                # other key/values
+                if validator.context.mappings.is_transform:
+                    continue
                 results.append(
                     (
                         None,
@@ -243,9 +249,9 @@ def find_in_map(validator: Validator, instance: Any) -> ResolutionResult:
                 ):
                     yield (
                         value,
-                        validator.evolve(
-                            context=validator.context.evolve(
-                                path=validator.context.path.evolve(
+                        second_v.evolve(
+                            context=second_v.context.evolve(
+                                path=second_v.context.path.evolve(
                                     value_path=deque(
                                         [
                                             "Mappings",
@@ -282,22 +288,28 @@ def get_azs(validator: Validator, instance: Any) -> ResolutionResult:
                 yield AVAILABILITY_ZONES.get(instance), v, None
 
 
-def _join_expansion(validator: Validator, instances: Any) -> Iterator[Any]:
+def _join_expansion(
+    validator: Validator, instances: Any
+) -> Iterator[tuple[Any, Validator]]:
     if len(instances) == 0:
         return
 
     if len(instances) == 1:
-        for value, _, _ in validator.resolve_value(instances[0]):
+        for value, instance_validator, _ in validator.resolve_value(instances[0]):
             if not isinstance(value, (str, int, float, bool)):
                 raise ValueError(f"Incorrect value type for {value!r}")
-            yield [value]
+            yield [value], instance_validator
         return
 
-    for value, _, _ in validator.resolve_value(instances[0]):
+    for value, instance_validator, errs in validator.resolve_value(instances[0]):
+        if errs:
+            continue
         if not isinstance(value, (str, int, float, bool)):
             raise ValueError(f"Incorrect value type for {value!r}")
-        for values in _join_expansion(validator, instances[1:]):
-            yield [value] + values
+        for values, expansion_validator in _join_expansion(
+            instance_validator, instances[1:]
+        ):
+            yield [value] + values, expansion_validator
 
 
 def join(validator: Validator, instance: Any) -> ResolutionResult:
@@ -310,12 +322,21 @@ def join(validator: Validator, instance: Any) -> ResolutionResult:
     for delimiter, delimiter_v, _ in validator.resolve_value(instance[0]):
         if not delimiter_v.is_type(delimiter, "string"):
             continue
-        for values, values_v, _ in validator.resolve_value(instance[1]):
+        for values, values_v, _ in delimiter_v.resolve_value(instance[1]):
             if not values_v.is_type(values, "array"):
                 continue
             try:
-                for value in _join_expansion(values_v, values):
-                    yield delimiter.join([str(v) for v in value]), values_v, None
+                for value, expansion_validator in _join_expansion(values_v, values):
+                    # reset the value path because we could get a Ref value_path
+                    yield delimiter.join(
+                        [str(v) for v in value]
+                    ), expansion_validator.evolve(
+                        context=expansion_validator.context.evolve(
+                            path=expansion_validator.context.path.evolve(
+                                value_path=deque([])
+                            )
+                        )
+                    ), None
             except (ValueError, TypeError):
                 return
 
@@ -415,7 +436,7 @@ def sub(validator: Validator, instance: Any) -> ResolutionResult:
             return
 
         string = instance[0]
-        parameters = instance[1]
+        parameters = deepcopy(instance[1])
         if not validator.is_type(string, "string"):
             return
         if not validator.is_type(parameters, "object"):
@@ -436,7 +457,11 @@ def sub(validator: Validator, instance: Any) -> ResolutionResult:
                     ref_values=resolved_parameters,
                 )
             )
-            yield from _sub_string(resolved_validator, string)
+            for sub_string, sub_validator, _ in _sub_string(resolved_validator, string):
+                for key in instance[1].keys():
+                    sub_validator.context.ref_values.pop(key, None)
+
+                yield sub_string, sub_validator, None
 
         return
 
@@ -455,7 +480,6 @@ def sub(validator: Validator, instance: Any) -> ResolutionResult:
             )
         )
         yield from _sub_string(resolved_validator, instance)
-        # yield from _sub_string(validator, instance)
 
 
 def if_(validator: Validator, instance: Any) -> ResolutionResult:
@@ -467,15 +491,21 @@ def if_(validator: Validator, instance: Any) -> ResolutionResult:
 
     for i in [1, 2]:
         for value, v, err in validator.resolve_value(instance[i]):
-            yield (
-                value,
-                v.evolve(
-                    context=v.context.evolve(
-                        path=v.context.path.evolve(value_path=deque([i])),
+            try:
+                yield (
+                    value,
+                    v.evolve(
+                        context=v.context.evolve(
+                            path=v.context.path.evolve(value_path=deque([i])),
+                            conditions=v.context.conditions.evolve(
+                                {instance[0]: True if i == 1 else False}
+                            ),
+                        ),
                     ),
-                ),
-                err,
-            )
+                    err,
+                )
+            except Unsatisfiable:
+                continue
 
 
 def to_json_string(validator: Validator, instance: Any) -> ResolutionResult:
